<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en_US">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>クリックしてアプリケーションに戻る</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>クリーンアップ</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0アイテム </translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>フォーム</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>ファイル名</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>再度試みてください</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開く</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>YouTubeにポッドキャストを公開</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>説明</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作成者</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>ボード</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>ウェブ</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>スタイラス</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T </translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>背景</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>背景を変える</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>取り消し</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>やり直し</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>前</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>前のページ</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>ページアップ</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>次</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>次のページ</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>ページダウン</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>ドキュメント管理</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>ウェブ閲覧 </translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>ライン</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>スモールライン</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>ミディアムライン</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>ラージライン</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>消しゴム</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">消しゴム（小）</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>消しゴム（中）</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>消しゴム（大）</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">カラー</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>前へ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>リロード</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>現在のページをリロード</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>ホーム</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>ホームページをロード</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>ブックマーク表示</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>ブックマークを追加</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>ボードを表示</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B </translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>消去</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>コンテンツを消去</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>表示設定</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>ライブラリ</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>ライブラリ表示</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L </translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>デスクトップを表示</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>コンピュータデスクトップを表示</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H </translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>より大きく</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>ズームイン</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++ </translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>より小さく</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>ズームアウト</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+- </translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新規フォルダー</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>新規フォルダーを作成</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>新規ドキュメント</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>新規ドキュメントを作成</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>インポート</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>ドキュメントをインポート</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>ドキュメントをエクスポート</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>ボード内に開く</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>ボード内にページを開く</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>複製する</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>選択したコンテンツを複製する</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>選択したコンテンツを削除する</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>作業中のドキュメントに追加</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>開かれたドキュメントに選択されたコンテンツを追加 </translation>
    </message>
    <message>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>コンテンツをドキュメントに追加</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>コンテンツの名前を変更</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>表示ツール</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>マルチスクリーン</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>ワイドサイズ (16/9) </translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>ワイドサイズ (16/9) ドキュメントの使用</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>レギュラーサイズ (4/3) </translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>レギュラーサイズ (4/3) ドキュメントの使用</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>カスタムサイズ</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>カスタムドキュメントサイズを使用</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>ローディングを中止</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>ウェブページのローディングを中止</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>カット</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>スリープ</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>プレゼンをスリープにする</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>バーチャルキーボード</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>バーチャルキーボード表示</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>プレーンライトの背景 </translation>
    </message>
    <message>
        <source>Light</source>
        <translation>ライト</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>グリッドライトの背景 </translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>プレーンダークの背景 </translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>ダーク</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>グリッドダークの背景 </translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>ポッドキャスト </translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>プレゼンをビデオに記録 </translation>
    </message>
    <message>
        <source>Record</source>
        <translation>記録</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>スクリーンレコーディングを開始</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>アイテムを消去</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>全アイテムを消去</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>注釈を消去</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>全注釈を消去</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>ページをクリア</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>全ページをクリア</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>ペン </translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>ドキュメントに注釈を加える</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I </translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>注釈を消去</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E </translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>マーカー</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>強調表示</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M </translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>セレクタ </translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>オブジェクトを選択して変更 </translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F </translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>ハンド</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>ページをスクロール</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>レーザーポインター</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>バーチャルレーザーポインター</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G </translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>線を描出 </translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J </translation>
    </message>
    <message>
        <source>Text</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>テキストを作成</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K </translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>キャプチャ</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>画面の一部をキャプチャ </translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>現在のページに追加</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>現在のページにアイテムを追加</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>新規ページに追加</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>新規ページにアイテムを追加</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>ライブラリに追加</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>ライブラリにアイテムを追加</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>ページ</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>新規ページ作成</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>新規ページ</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>ページを複製</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>現在のページを複製</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>ページをインポート</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>外部のページをインポート</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>一時停止</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>ポッドキャストのレコーディングを一時停止 </translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>ポッドキャスト設定</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>ポッドキャストレコーディング設定 </translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation>フラッシュトラップ</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation>トラップフラッシュコンテンツ</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>ウェブトラップ </translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>トラップウェブコンテンツ</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>カスタムキャプチャ</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>ウィンドウキャプチャ</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>ウィンドウをキャプチャ</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>ウェブコンテンツを埋め込む</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>埋め込み可能ウェブコンテンツをキャプチャ</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>ディスプレイ上に表示</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>ディスプレイ画面にメインスクリーンを表示</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>全注釈を消去</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia </translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMediaシミュレーションのインポート</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>更新をチェック</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H </translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Open-Sankoreを終了</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>OpenBoardを隠す</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>OpenBoardを隠す</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>始動する</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>アイテムを使う</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>背景を削除する</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>背景を削除する</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>認証が必要</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>パスワード:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>プロキシ認証</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>プロキシに接続</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>ユーザー名:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>パスワード： </translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>今後の使用のためにユーザー名とパスワードを保存</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Remove Page</source>
        <translation type="unfinished">ページ削除</translation>
    </message>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>ページサイズ</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>ポッドキャスト </translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>ウェブ</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>新しい更新が利用可能です。ウェブページへ移動しますか？ </translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>利用可能な更新はありません </translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>更新が利用可能です</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>コンテンツ%1のダウンロードに失敗 </translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>ダウンロード終了</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>不明のツールタイプ%1 </translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>不明のコンテンツタイプ%1 </translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>アイテムの追加</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>全てサポート(%1) </translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">カラー</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>ライブラリに画像追加中にエラー</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>キャプチャされた画像</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>キャッシュプロパティ </translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>カラー: </translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>形状： </translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>サイズ： </translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>画面の一部をキャプチャ </translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>画面をキャプチャ</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>スタイラスパレットを表示</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>サブスクリーンにボードを表示 </translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>サブスクリーンにデスクトップを表示 </translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>新規フォルダー</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>%1ページ</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>画像フィルダーを追加</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>画像を追加</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>ファイルからページを追加</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>ドキュメント%1の複製</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>ドキュメント%1コピー済み</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">ページ削除</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">ドキュメント削除 </translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">本当にドキュメント%1を削除しますか？</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">ゴミ箱を空にする</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">本当にこのゴミ箱を空にしますか？</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">ゴミ箱を空にしています</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">ゴミ箱を空にしました</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">フォルダーを削除</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">本当にフォルダー%1とそのコンテンツを削除しますか？</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">ドキュメントが選択されていません！</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>サポートされたファイルを開く</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>ファイル%1のインポート中... </translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>ファイルのインポートに失敗…  </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>フォルダーから全ての画像をインポート</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>空</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>ゴミ箱</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>ドキュメントを開く</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>すべての画像をドキュメントに追加</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>全画像(%1) </translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>選択には画像ファイルが含まれていません！ </translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>選抜した資料から%nページを除けたいですか？</numerusform>
        </translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation type="unfinished">タイトルなしドキュメント</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>画像</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>オブジェクト</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>全てサポートされているファイル(*.%1) </translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>ファイル%1保存済み </translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished">インポートに成功。</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>%0ページ</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">ゴミ箱</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>ページを%1枚をコピーしました</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>ページを%1枚をコピーしました</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">%1/%2 ページ コピー中</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (コピー) </translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">%1/%2 ページ コピー中</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>ページを%1枚をコピーしました</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>ファイルをダウンロードしています</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0ページ</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0ページ</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings during export was appeared</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>IWBへエクスポート</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>IWB ファイルとしてエクスポート</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>エクスポートに成功 </translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>エクスポートに失敗 </translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>ページ</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>UBZ ファイルとしてエクスポート</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">エクスポートに成功 </translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>%1 %2 / %3 をエクスポート中</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDFファイルとしてエクスポート</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">エクスポートに成功 </translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDFへエクスポート</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>PDFファイルとしてエクスポート</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">エクスポートに成功。</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>%1 / %2 ページのエクスポート中</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>PDFへエクスポート</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>ページ</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>ウェブデータとしてエクスポート</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>ドキュメントのエクスポート中... </translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>エクスポートに成功。</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>エクスポートに失敗。</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>ウェブブラウザへエクスポート</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>ページに追加 </translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">背景として設定</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>ライブラリに追加</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>オブジェクトインフォーメーション</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>お気に入りに追加</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>シェアする</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>フォルダーに戻る</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>お気に入りから削除</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>新規フォルダーを作成</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>ファイルを更新する</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>インポートされた画像</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation type="unfinished">オーディオ</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished">ムービー</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished">写真</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="obsolete">動画</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation type="unfinished">インタラクティブ</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished">アプリケーション</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation type="unfinished">形状</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished">ゴミ箱</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation type="unfinished">ロック</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation type="unfinished">拡張画面でみることができます </translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>ロック</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>拡張画面でみることができます </translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>コンテンツのソースへ移動 </translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">背景として設定</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>〈ここへテキストを入力〉 </translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>テキストカラー</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>編集できます</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation type="unfinished">ウェブ</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation type="unfinished">ローディング中… </translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>凍結</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>ツールとして変換  </translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>共通ファイルフォーマット ( </translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>ファイル%1のインポート中... </translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>ファイル%1のインポート失敗。</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>インポートに成功。</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>インポート失敗。</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>ファイル%1のインポート中... </translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>インポートに成功。</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>ファイル%1のインポート失敗。</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>画像フォーマット（</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>ポータブル・ドキュメント・フォーマット (*.pdf) </translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDFインポートに失敗。</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>%1 / %2 ページをインポート</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>ビデオをイントラネットに公開中にエラー(%1) </translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>イントラネットに公開進行中%1 % </translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>公開</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">閉じる</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;&quot;%1&quot;の %2におけるユーザー名とパスワードを入力&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>プロキシへのログインに失敗</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSLエラー:

%1

%2

このホストのエラーは無視しますか？ 
</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">キャンセル</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(コピー)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>ドキュメント・リポジトリ･ロス</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>英語</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>ロシア語</translation>
    </message>
    <message>
        <source>French</source>
        <translation>フランス語</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>スイスのフランス語</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>エンコーダ開始に失敗 ... </translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>利用可能なポッドキャストエンコーダーがありません </translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>パート%1 </translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>デスクトップ上 ... </translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>フォルダー%1内</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>ポッドキャスト作成 %1 </translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>ポッドキャスト記録エラー(%1) </translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>デフォルトオーディオインプット</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>オーディオ記録がありません</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>スモール</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>ミディアム</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>フル</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>イントラネットに公開</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Youtubeに公開</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>感圧性マーカー</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">プロキシログイン</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">ユーザー名： </translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">パスワード： </translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">ドキュメントをウェブに公開</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">タイトル： </translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">説明： </translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">公開</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>マイ・ムービー </translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>プレビュー･サムネイル作成中 ... </translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 サムネイル作成済み ... </translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">%0ページ</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>マスク</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>ルーラ</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>コンパス</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>分度器</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>三角定規</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>拡大鏡</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>キャッシュ</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>ページ全体</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>ウェブ</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>ドキュメントアップデータ</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>ファイルは更新を必要としています </translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>バックアップパス:  </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>ブラウズ</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>更新</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>バックアップフォルダーを選択 </translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>ファイル更新に成功!
アプリケーションを再起動して更新ファイルにアクセスしてください。</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>更新中にエラーが発生しました。ファイルに影響はありません。 </translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>ファイル更新結果</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>ファイル更新中  </translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>少々お待ちください、インポート処理を開始します...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>あとで覚える</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>ロード中… </translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 コール(メソッド=%1, ステータス=%2) </translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube 認証に失敗 </translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>ビデオをYouTubeへアップロード中にエラー(%1) </translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>YouTubeへアップロード進行中%1 % </translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>自動車 &amp; 乗り物</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音楽 </translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>ペット &amp; 動物</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>スポーツ </translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>旅行 &amp; イベント</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>ゲーム</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>コメディー </translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>人々 &amp; ブログ</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>ニュース &amp; 政治 </translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>エンタテイメント </translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>ハウツー &amp; スタイル</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>非営利団体 &amp; アクティビズム</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>科学 &amp; 技術</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x </translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>クリア</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>ファイルを保存</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>キャンセルされたダウンロード: %1 </translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>保存されたファイルを開く時にエラー: %1 </translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>保存時にエラー: %1 </translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>ネットワークエラー: %1 </translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>残り - %4 %5 </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 / %2 (%3/秒) %4 </translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation> ? </translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 / %2 – 中止</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>バイト</translation>
    </message>
    <message>
        <source>KB</source>
        <translation> KB </translation>
    </message>
    <message>
        <source>MB</source>
        <translation> MB </translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 ダウンロード</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1ダウンロード</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>アドレス</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>今日</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 アイテム </translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>新規 &amp; タブ</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>クローンタブ</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp; タブを閉じる</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>他のタブを&amp;閉じる</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>タブをリロード</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>全タブをリロード</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>最近閉じたタブ</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>（タイトルなし）</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>最近の検索なし</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>最近の検索</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>最近の検索のクリア</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>現在のドキュメントに追加</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>ページのロード中にエラー: %1 </translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>新規タブ内で開く</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>YouTubeにポッドキャストを公開</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>説明</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>キーワード</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>カテゴリー</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTubeユーザー名</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTubeパスワード</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>明るい背景で</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>暗い背景で</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>不透明性 </translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>線の幅</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>太</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>細</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>ペンは感圧性です。</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>Eメール</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>作成者</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>説明</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">ダイアログ</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">タイトル</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">Eメール</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">作成者</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">説明</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>バージョン: …</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>デフォルト設定 </translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>インターネット</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>外部ブラウザでページを表示 </translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>ホームページ:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>バーチャルキーボード</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">キーボードボタンサイズ: </translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>上部に配置 (タブレット向け) </translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>下部に配置 (ホワイトボード向け) </translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>ボタン下にテキストを表示</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>スタイラスパレット </translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>水平方向</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>垂直方向</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>ペン </translation>
    </message>
    <message>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>ソフトウェア更新</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>起動時にソフトウェア更新をチェックする </translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>ネットワーク</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>映写機や二号スクリーンにウエブページを掲示する</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>複数表記</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>点検表記と視覚表記を逆にする</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>最初モード：</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>ボード</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>プロキシ利用者：</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>パスワード：</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">暗い背景で</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">不透明性 </translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">明るい背景で</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished">マーカー</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>トラップフラッシュ</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation>フラッシュを選択してトラップする</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>情報:ブランク</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>アプリケーション名</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>アプリケーションを作成</translation>
    </message>
</context>
</TS>
